.. craft-archives documentation root file

Craft Archives
==============

Craft Archives is a Python package that manages interactions with software package
repositories on behalf of tools that use the Craft Parts library.

It provides a set of common interfaces to locate and install repositories.

It aims to provide a uniform, extensible set of interfaces that other tools and
packages can use when working with repositories.

This package is most useful for developers who write tools with Craft Parts
and need to provide support for additional software package repositories.

.. toctree::
   :maxdepth: 1
   :hidden:

   how-to-guides/index
   reference/index
   explanation/index

.. list-table::

    * - | :ref:`How-to guides <how-to-guides>`
        | **Step-by-step guides** covering key operations and common tasks
    * - | :ref:`Reference <reference>`
        | **Technical information** about Craft Archives
    * - | :ref:`Explanation <explanation>`
        | **Discussion and clarification** of key topics


Project and community
---------------------

Craft Archives is a member of the Canonical family. It's an open source project that
warmly welcomes community projects, contributions, suggestions, fixes and constructive
feedback.

* `Ubuntu Code of Conduct <https://ubuntu.com/community/code-of-conduct>`_.
* `Canonical contributor licenses agreement <https://ubuntu.com/legal/contributors>`_.
